Module play

Module play 

PLAY and CONFIG state packets needed for server switching and command interception.

Most PLAY packets are relayed as opaque frames. Only the packets needed for /server command interception and the CONFIG state transition are defined here.

Structs

ConfigPacketIds
CONFIG state packet IDs (stable across all 1.21+ versions).
PlayPacketIds
Version-specific PLAY packet IDs.

Functions

parse_command_from_signed
Parse the command string from a signed player command packet.
parse_command_from_unsigned
Parse the command string from an unsigned player command packet.