read_properties

Function read_properties 

pub fn read_properties(
    buf: &mut impl Buf,
) -> Result<Vec<ProfileProperty>, ProtocolError>
Read a game profile’s properties array from the Minecraft protocol format.

Errors

Returns PropertyCountExceeded if the declared count is negative or exceeds [MAX_PROPERTIES]. Returns other protocol errors if the data is malformed.