read_string_max

Function read_string_max 

pub fn read_string_max(
    buf: &mut impl Buf,
    max_len: usize,
) -> Result<String, ProtocolError>
Read a Minecraft protocol string with a custom maximum length.

Errors

Returns an error if the string length exceeds max_len or UTF-8 decoding fails.