Minecraft protocol version definitions.
Only versions 1.21+ are supported. Each entry maps a protocol number to the Minecraft release versions that use it.
Enums
- Protocol
Version - Minecraft protocol version.
Minecraft protocol version definitions.
Only versions 1.21+ are supported. Each entry maps a protocol number to the Minecraft release versions that use it.