ProtocolVersion

Enum ProtocolVersion 

pub enum ProtocolVersion {
    V1_21,
    V1_21_2,
    V1_21_4,
    V1_21_5,
    V1_21_6,
    V1_21_7,
    V1_21_9,
    V1_21_11,
}
Minecraft protocol version.

Variants



V1_21

1.21, 1.21.1 (protocol 767)



V1_21_2

1.21.2, 1.21.3 (protocol 768)



V1_21_4

1.21.4 (protocol 769)



V1_21_5

1.21.5 (protocol 770)



V1_21_6

1.21.6 (protocol 771)



V1_21_7

1.21.7, 1.21.8 (protocol 772)



V1_21_9

1.21.9, 1.21.10 (protocol 773)



V1_21_11

1.21.11 (protocol 774)

Implementations

Source

impl ProtocolVersion

pub const MINIMUM: Self = Self::V1_21

The minimum supported protocol version.

pub const MAXIMUM: Self = Self::V1_21_11

The maximum supported protocol version.

pub const MINIMUM_PROTOCOL: i32 = 767

The minimum protocol number we accept.

pub const MAXIMUM_PROTOCOL: i32 = 774

The maximum protocol number we accept.

pub const SUPPORTED_VERSIONS: &'static str = "1.21-1.21.11"

The supported version range as a human-readable string.

pub const fn from_protocol(protocol: i32) -> Option<Self>

Create a ProtocolVersion from a protocol number.

Returns None if the protocol number is not supported.

pub const fn protocol(self) -> i32

Get the protocol number for this version.

pub const fn name(self) -> &'static str

Get a human-readable version string.

pub const fn at_least(self, other: Self) -> bool

Check if this version is at least the given version.