PLAY and CONFIG state packets needed for server switching and command interception.
Most PLAY packets are relayed as opaque frames. Only the packets needed for
/server command interception and the CONFIG state transition are defined here.
Structs
- Config
Packet Ids - CONFIG state packet IDs (stable across all 1.21+ versions).
- Play
Packet Ids - Version-specific PLAY packet IDs.
Functions
- parse_
command_ from_ signed - Parse the command string from a signed player command packet.
- parse_
command_ from_ unsigned - Parse the command string from an unsigned player command packet.