pub fn parse_command_from_unsigned(payload: &[u8]) -> Option<String>Expand description
Parse the command string from an unsigned player command packet.
The wire format is simply a VarInt-prefixed UTF-8 string (the command
without the leading /). This is the first (and only meaningful) field.
Errors
Returns None if the data is too short to contain a valid string.